@@ -3,14 +3,15 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::Bugtracker;
-our $VERSION = '1.100701';
-
-# ABSTRACT: automatically sets the bugtracker URL
+BEGIN {
+  $Dist::Zilla::Plugin::Bugtracker::VERSION = '1.101420';
+}
+# ABSTRACT: Automatically sets the bugtracker URL
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
 
 sub metadata {
-    my ($self, $arg) = @_;
+    my $self = shift;
     return {
         resources => {
             bugtracker =>
@@ -29,11 +30,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Plugin::Bugtracker - automatically sets the bugtracker URL
+Dist::Zilla::Plugin::Bugtracker - Automatically sets the bugtracker URL
 
 =head1 VERSION
 
-version 1.100701
+version 1.101420
 
 =head1 SYNOPSIS
 
@@ -58,6 +59,25 @@ __END__
 
 See perlmodinstall for information and options on installing Perl modules.
 
+=head1 BUGS AND LIMITATIONS
+
+No bugs have been reported.
+
+Please report any bugs or feature requests through the web interface at
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Bugtracker>.
+
+=head1 AVAILABILITY
+
+The latest version of this module is available from the Comprehensive Perl
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see
+L<http://search.cpan.org/dist/Dist-Zilla-Plugin-Bugtracker/>.
+
+The development version lives at
+L<http://github.com/hanekomu/Dist-Zilla-Plugin-Bugtracker/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHOR
 
   Marcel Gruenauer <marcel@cpan.org>
